sott
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

`sott` implements pixel offset tracking method based on amplitude of SAR
images or optical images.

## Install

    conda install -c conda-forge sott

## How to use

``` python
import sott as ot
```

Please refer to the [Documentation](https://kanglcn.github.io/hot-pot)
for detailed usage.
